local MinimapModule = Dominos:NewModule('Minimap')
local MinimapFrame = Dominos:CreateClass('Frame', Dominos.Frame)
--[[ Module Code ]]--

function MinimapModule:Load()
	self.frame = MinimapFrame:New()
end

function MinimapModule:Unload()
	self.frame:Free()

end

--[[ Minimap Frame Code ]]--

function MinimapFrame:New()
	local f = self.super.New(self, 'minimap')
	self.sets = MinimapFrame:GetDefaults()
	if not self.MinimapContainer then
		f:CreateMinimap()
		f:SetFrameStrata('LOW')
	end
	f:Layout()
	return f
end

function MinimapFrame:GetDefaults()
	return {
		scale = 1,
		point = 'CENTER',
		y = 0,
		x = 0,
		pad = 0,
	}
end

function MinimapFrame:CreateMinimap()
	if not self.MinimapContainer then
		self.MinimapContainer = Minimap:GetContainer(self, Dominos)
	end
end

function MinimapFrame:Layout()
	self.sets.pad = self.sets.pad or 0
	self.sets.secondScale = self.sets.secondScale or 100
	Minimap:Settings(self.sets, self.sets.secondScale/ 100)
	
	local size = self.MinimapContainer:GetWidth() 
	self:SetSize(size + self.sets.pad, size + self.sets.pad)
end


--[[ Menu Code ]]--

local function CreatePaddingSlider(p)
	local s = p:NewSlider("Padding", -19, 100, 1)
	s.OnShow = function(self)
		self:SetValue(self:GetParent().owner.sets.pad)
	end
	s.UpdateValue = function(self, value)
		local f = self:GetParent().owner
		f.sets.pad = value
		f:Layout()
	end
end

local function CreateSecondaryScale(p)
	local s = p:NewSlider("Minimap Scale", 50, 150, 1)
	s.OnShow = function(self)
		self:SetValue(self:GetParent().owner.sets.secondScale)
	end
	s.UpdateValue = function(self, value)
		local f = self:GetParent().owner
		f.sets.secondScale = value
		f:Layout()
	end
end

function MinimapFrame:LeftToRight(enable)
	self.sets.LtR = enable or nil
	self:Layout()
end

function MinimapFrame:TopToBottom(enable)
	self.sets.TtB = enable or nil
	self:Layout()
end

local function AddLayoutPanel(menu)
	local p = menu:NewPanel(LibStub('AceLocale-3.0'):GetLocale('Dominos-Config').Layout)
	CreateSecondaryScale(p)
	p:NewOpacitySlider()
	p:NewFadeSlider()
	p:NewScaleSlider()
	CreatePaddingSlider(p)

	local LtR = p:NewCheckButton("Buttons on Left")
	LtR:SetScript('OnClick', function(self) self:GetParent().owner:LeftToRight(self:GetChecked()) end)
	LtR:SetScript('OnShow', function(self) self:SetChecked(self:GetParent().owner.sets.LtR) end)
	
	local TtB = p:NewCheckButton("Zone Text on Bottom")
	TtB:SetScript('OnClick', function(self) self:GetParent().owner:TopToBottom(self:GetChecked()) end)
	TtB:SetScript('OnShow', function(self) self:SetChecked(self:GetParent().owner.sets.TtB) end)
end

function MinimapFrame:CreateMenu()
	local menu = Dominos:NewMenu(self.id)
	AddLayoutPanel(menu)
	self.menu = menu
end

local f = CreateFrame("Frame")
f:RegisterEvent("ADDON_LOADED")
f:SetScript("OnEvent", function(self, event, name)
    if name == "Blizzard_TimeManager" then
        TimeManagerClockButton:Hide()
        TimeManagerClockButton:SetScript("OnShow", function(self)
            TimeManagerClockButton:Hide()
        end)
    end
end)
